@@ -14,7 +14,6 @@ EXPOSED_RPCS: Tuple[Type[RPC], ...] = (
     rpc.StopPackage,
     rpc.PausePackage,
     rpc.ResumePackage,
-    rpc.PackageState,
     rpc.UploadPackage,
     rpc.ListPackages,
     rpc.DeletePackage,
@@ -28,8 +27,8 @@ EVENTS: Tuple[Type[arcor2_events.Event], ...] = (
     arcor2_events.PackageState,
     arcor2_events.PackageInfo,
     arcor2_events.ProjectException,
-    arcor2_events.CurrentAction,
-    arcor2_events.ActionState,
+    arcor2_events.ActionStateBefore,
+    arcor2_events.ActionStateAfter,
 )
 
 
